[dh-make-perl] 03/04: fix a bunch of typos thanks to Test::Spelling

Damyan Ivanov dmn at alioth.debian.org
Fri Aug 9 13:50:11 UTC 2013


This is an automated email from the git hooks/post-receive script.

dmn pushed a commit to branch master
in repository dh-make-perl.

commit 73092459567356a62ac2f3fd558fcc55e639f2fd
Author: Damyan Ivanov <dmn at debian.org>
Date:   Fri Aug 9 15:10:29 2013 +0200

    fix a bunch of typos thanks to Test::Spelling
---
 lib/Debian/AptContents.pm                   |    8 ++++----
 lib/Debian/Control/FromCPAN.pm              |    4 ++--
 lib/Debian/Control/Stanza.pm                |    2 +-
 lib/Debian/Control/Stanza/CommaSeparated.pm |    4 ++--
 lib/Debian/Dependencies.pm                  |    8 ++++----
 lib/Debian/Dependency.pm                    |    2 +-
 lib/Debian/Rules.pm                         |   10 +++++-----
 lib/Debian/WNPP/Bug.pm                      |    4 ++--
 lib/Debian/WNPP/Query.pm                    |    2 +-
 lib/DhMakePerl/Command/Packaging.pm         |    8 ++++----
 lib/DhMakePerl/Config.pm                    |    2 +-
 lib/DhMakePerl/PodParser.pm                 |    6 +++---
 lib/DhMakePerl/Utils.pm                     |    8 ++++----
 13 files changed, 34 insertions(+), 34 deletions(-)

diff --git a/lib/Debian/AptContents.pm b/lib/Debian/AptContents.pm
index f945e44..71ca91d 100644
--- a/lib/Debian/AptContents.pm
+++ b/lib/Debian/AptContents.pm
@@ -155,7 +155,7 @@ sub warning {
 
 =item repo_source_to_contents_paths
 
-Given a line with Deban package repository path (typically taken from
+Given a line with Debian package repository path (typically taken from
 F<sources.list>), converts it to the corresponding F<Contents> file names.
 
 =cut
@@ -360,8 +360,8 @@ sub read_cache {
 
 Writes the contents of the parsed C<cache> to the C<cache_file>.
 
-Storable is used to stream the data. Along woth the information from
-F<Contents> files, a timestamp is stored.
+Storable is used to stream the data. Along with the information from
+F<Contents> files, a time stamp is stored.
 
 =cut
 
@@ -399,7 +399,7 @@ sub find_file_packages {
     return () unless $packages;
 
     my @packages = split( /,/, $packages );    # Contents contains a
-                                               # comma-delimitted list
+                                               # comma-delimited list
                                                # of packages
 
     s{.+/}{} for @packages;                    # remove section. Greedy on purpose
diff --git a/lib/Debian/Control/FromCPAN.pm b/lib/Debian/Control/FromCPAN.pm
index ea57603..bc63605 100644
--- a/lib/Debian/Control/FromCPAN.pm
+++ b/lib/Debian/Control/FromCPAN.pm
@@ -54,7 +54,7 @@ The directory where the cpan distribution was unpacked.
 =item intrusive
 
 A flag indicating permission to use L<Module::Depends::Intrusive> for
-discovering dependencies in case L<Module::Depends> fails. Sinse this requires
+discovering dependencies in case L<Module::Depends> fails. Since this requires
 loading all Perl modules in the distribution (and running their BEGIN blocks
 (and the BEGIN blocks of their dependencies, recursively), it is recommended to
 use this only when dealing with trusted sources.
@@ -69,7 +69,7 @@ be found. Otherwise only a warning is issued.
 =item wnpp_query
 
 An instance of L<Debian::WNPP::Query> to be used when checking for WNPP bugs of
-depeended upon packages.
+depended upon packages.
 
 =back
 
diff --git a/lib/Debian/Control/Stanza.pm b/lib/Debian/Control/Stanza.pm
index eda234e..58f6114 100644
--- a/lib/Debian/Control/Stanza.pm
+++ b/lib/Debian/Control/Stanza.pm
@@ -35,7 +35,7 @@ use Debian::Dependencies;
 
 =head1 FIELDS
 
-Stanza fields are to be defined in the class method I<fields>. Tyically this
+Stanza fields are to be defined in the class method I<fields>. Typically this
 can be done like:
 
     use constant fields => qw( Foo Bar Baz );
diff --git a/lib/Debian/Control/Stanza/CommaSeparated.pm b/lib/Debian/Control/Stanza/CommaSeparated.pm
index 4ee15d7..d728aec 100644
--- a/lib/Debian/Control/Stanza/CommaSeparated.pm
+++ b/lib/Debian/Control/Stanza/CommaSeparated.pm
@@ -16,7 +16,7 @@ use Text::ParseWords qw(quotewords);
 
 use overload '""' => \&as_string;
 
-=head1 SYNOPSYS
+=head1 SYNOPSIS
 
     my $f = Debian::Control::Stanza::CommaSeparated->new(
         'Joe M <joem at there.not>');
@@ -91,7 +91,7 @@ sub _parse {
 
 =item add I<@items>
 
-Adds the ginen items to the list. Items that are already present are not added,
+Adds the given items to the list. Items that are already present are not added,
 keeping the list unique.
 
 =cut
diff --git a/lib/Debian/Dependencies.pm b/lib/Debian/Dependencies.pm
index e6481b0..76187c4 100644
--- a/lib/Debian/Dependencies.pm
+++ b/lib/Debian/Dependencies.pm
@@ -35,7 +35,7 @@ Debian::Dependencies - a list of Debian::Dependency objects
 
     print Debian::Dependencies->new('perl')
           + Debian::Dependency->new('foo');
-                              # add depeendency to a list
+                              # add dependency to a list
 
 =head1 DESCRIPTION
 
@@ -47,7 +47,7 @@ as arrayrefs, as long as the elements you put in them are instances of the
 L<Debian::Dependency> class.
 
 When used in string context, Debian::Dependencies converts itself into a
-comma-delimitted list of dependencies, suitable for dependency fields of
+comma-delimited list of dependencies, suitable for dependency fields of
 F<debian/control> files.
 
 =head2 CLASS METHODS
@@ -58,7 +58,7 @@ F<debian/control> files.
 
 Constructs a new L<Debian::Dependencies> object. Accepts one scalar argument,
 which is parsed and turned into an arrayref of L<Debian::Dependency> objects.
-Each dependency should be delimitted by a comma and optional space. The exact
+Each dependency should be delimited by a comma and optional space. The exact
 regular expression is C</\s*,\s*/>.
 
 =cut
@@ -251,7 +251,7 @@ sub prune {
 
 =item sort()
 
-Sorts the dependency list by packagee name, version and relation.
+Sorts the dependency list by package name, version and relation.
 
 =cut
 
diff --git a/lib/Debian/Dependency.pm b/lib/Debian/Dependency.pm
index 3ce1f98..6d94321 100644
--- a/lib/Debian/Dependency.pm
+++ b/lib/Debian/Dependency.pm
@@ -55,7 +55,7 @@ use overload '""' => \&_stringify,
 
 =item new()
 
-Construnct a new instance.
+Construct a new instance.
 
 =item new( { pkg => 'package', rel => '>=', ver => '1.9' } )
 
diff --git a/lib/Debian/Rules.pm b/lib/Debian/Rules.pm
index 7bfe49d..cb4ba18 100644
--- a/lib/Debian/Rules.pm
+++ b/lib/Debian/Rules.pm
@@ -98,7 +98,7 @@ sub new {
 Parses the rules file and stores its findings for later use. Called
 automatically by L<is_dh7tiny> and L<is_quiltified>. The result of the parsing
 is cached and subsequent calls to C<is_XXX> use the cache. To force cache
-refresh (for eample if the contents of the file have been changed), call
+refresh (for example if the contents of the file have been changed), call
 C<parse> again.
 
 =cut
@@ -129,8 +129,8 @@ sub parse {
 =item is_dh7tiny
 
 Returns true if the contents of the rules file seem to use the so called
-I<tiny> variant offerred by debhelper 7. Tiny rules are detected by the
-presense of the following two lines:
+I<tiny> variant offered by debhelper 7. Tiny rules are detected by the
+presence of the following two lines:
 
     %:
             dh $@
@@ -174,7 +174,7 @@ sub is_quiltified {
 
 Integrates L<quilt(1)> into the rules. For debhelper 7 I<tiny> rules (as
 determined by L</is_dh7tiny>) C<--with=quilt> is added to every C<dh>
-invocation. For the more traditional variant, quilt is integrated vua
+invocation. For the more traditional variant, quilt is integrated via
 F<quilt.make> and its C<< $(QUILT_STAMPFN) >> and C<unpatch> targets.
 
 =cut
@@ -315,7 +315,7 @@ sub drop_quilt {
     }
 }
 
-=item read [I<filename>]
+=item read [I<file name>]
 
 Replaces the current rules content with the content of I<filename>. If
 I<filename> is not given, uses the value of the L</filename> member.
diff --git a/lib/Debian/WNPP/Bug.pm b/lib/Debian/WNPP/Bug.pm
index 9d999ee..3250187 100644
--- a/lib/Debian/WNPP/Bug.pm
+++ b/lib/Debian/WNPP/Bug.pm
@@ -99,7 +99,7 @@ The short description of the package
 
 =item submitter
 
-The bug sumbitter in the form C<< Full Name <email at address> >>
+The bug submitter in the form C<< Full Name <email at address> >>
 
 =back
 
@@ -136,7 +136,7 @@ sub type_and_number {
 
 =item as_string
 
-Uset for the "" overload. Returns the bug number.
+Used for the "" overload. Returns the bug number.
 
 =cut
 
diff --git a/lib/Debian/WNPP/Query.pm b/lib/Debian/WNPP/Query.pm
index 24a62bc..d7d993d 100644
--- a/lib/Debian/WNPP/Query.pm
+++ b/lib/Debian/WNPP/Query.pm
@@ -67,7 +67,7 @@ sub new {
         { map( ( $_ => 1 ), @{ $self->bug_types || [ keys %list_url ] } ), }
     );
 
-    # default ttl
+    # default TTL
     $self->ttl( 24 * 3600 )
         unless defined $self->ttl;
 
diff --git a/lib/DhMakePerl/Config.pm b/lib/DhMakePerl/Config.pm
index 7e19b83..6537211 100644
--- a/lib/DhMakePerl/Config.pm
+++ b/lib/DhMakePerl/Config.pm
@@ -296,7 +296,7 @@ sub dump_config {
 
 =item check_obsolete_entries
 
-Checks for presense of deprecated/obsolete entries and warns/dies if any is
+Checks for presence of deprecated/obsolete entries and warns/dies if any is
 found.
 
 =cut
diff --git a/lib/DhMakePerl/PodParser.pm b/lib/DhMakePerl/PodParser.pm
index 0fa1a99..117def9 100644
--- a/lib/DhMakePerl/PodParser.pm
+++ b/lib/DhMakePerl/PodParser.pm
@@ -14,7 +14,7 @@ DhMakePerl::PodParser - internal helper module for DhMakePerl
 =head1 SYNOPSIS
 
 DhMakePerl::PodParser is used by DhMakePerl to extract some
-information from the module-to-be-packaged. It subclasses from
+information from the module-to-be-packaged. It sub-classes from
 L<Pod::Parser> - Please refer to it for further documentation.
 
 =head1 METHODS
@@ -87,7 +87,7 @@ sub command {
 
 =item add_text
 
-Hands back the text it received as it ocurred in the input stream (see the
+Hands back the text it received as it occurred in the input stream (see the
 L<Pod::Parser>'s documentation for L<verbatim|Pod::Parser/verbatim>,
 L<textblock|Pod::Parser/textblock> and
 L<interior_sequence|Pod::Parser/interior_sequence>).
@@ -128,7 +128,7 @@ sub textblock { shift->add_text(@_) }
 =item interior_sequence
 
 L<interior_sequence()|Pod::Parser/interior_sequence()> is called by
-L<Pod::Parser> when, eh, an interiorsquence occureds in the text. Interior
+L<Pod::Parser> when, eh, an interior sequence occurs in the text. Interior
 sequences are things like IE<lt>...E<gt>.
 
 This implementation decodes C<gt>, C<lt>, C<sol>, C<verbar> and numeric
diff --git a/lib/DhMakePerl/Utils.pm b/lib/DhMakePerl/Utils.pm
index 3caa0be..53b0cd2 100644
--- a/lib/DhMakePerl/Utils.pm
+++ b/lib/DhMakePerl/Utils.pm
@@ -7,7 +7,7 @@ our $VERSION = '0.71';
 
 =head1 NAME
 
-DhMakePerl::Utils - helper routined for dh-make-perl and alike
+DhMakePerl::Utils - helper routines for dh-make-perl and alike
 
 =head1 SYNOPSIS
 
@@ -120,7 +120,7 @@ sub is_core_module {
 
 =item nice_perl_ver I<version_string>
 
-Reformats perl version to match Debian's perl package versions.
+Re-formats perl version to match Debian's perl package versions.
 
 For example C<5.010> (and C<5.01>) is converted to C<5.10>.
 
@@ -235,12 +235,12 @@ sub find_core_perl_dependency {
 
 =item split_version_relation I<string>
 
-Splits the string, typicaly found in dependency fields' values in CPAN META
+Splits the string, typically found in dependency fields' values in CPAN META
 into relation and version. If no relation is found in the string, C<< >= >> is
 assumed.
 
 Returns a list of relation and version. The relation is suitable for using in
-debian package dependency version requirements.
+Debian package dependency version requirements.
 
 For example
 

diff --git a/lib/DhMakePerl/Command/Packaging.pm b/lib/DhMakePerl/Command/Packaging.pm
index 74149b9..183bb75 100644
--- a/lib/DhMakePerl/Command/Packaging.pm
+++ b/lib/DhMakePerl/Command/Packaging.pm
@@ -94,7 +94,7 @@ sub main_file {
 
 =item debian_file(file_name)
 
-Constructs a file name relative to the debian/ subdurectory of the main source
+Constructs a file name relative to the debian/ sub-directory of the main source
 directory.
 
 =cut
@@ -1081,8 +1081,8 @@ sub create_copyright {
                     when (/apache_2_0/) { $licenses{'Apache-2.0'} = 1; }
                     when (/artistic_1/) { $licenses{'Artistic'} = 1; }
                     when (/artistic_2/) { $licenses{'Artistic-2.0'} = 1; }
                     # EU::MM and M::B converts the unversioned 'gpl' to gpl_1.
                     # As a unversioned GPL means *any* GPL,I think it's safe to use GPL-1+ here
                     when (/gpl_1/) { $licenses{'GPL-1+'} = 1; }
 
                     when (/perl_5/) {
@@ -1456,7 +1456,7 @@ The proper build-dependency in this case is
 
     perl
 
-The unversioned dependency on perl is set as Lenny has already 5.10 which
+The on perl without a version is set as Lenny has already 5.10 which
 includes first Module::Build.
 
 =back
@@ -1081,8 +1081,8 @@ sub create_copyright {
                     when (/artistic_1/) { $licenses{'Artistic'} = 1; }
                     when (/artistic_2/) { $licenses{'Artistic-2.0'} = 1; }
-                    # EU::MM and M::B converts the unversioned 'gpl' to gpl_1.
-                    # As a unversioned GPL means *any* GPL,I think it's safe to use GPL-1+ here
+                    # EU::MM and M::B converts the 'gpl' without a version to gpl_1.
+                    # As GPL without a version means *any* GPL, I think it's safe to use GPL-1+ here
                     when (/gpl_1/) { $licenses{'GPL-1+'} = 1; }
 
-- 
Alioth's /usr/local/bin/git-commit-notice on /srv/git.debian.org/git/pkg-perl/packages/dh-make-perl.git



More information about the Pkg-perl-cvs-commits mailing list